ziggy

Package ziggy |
[hide private]
[frames] | no frames]

# Package ziggy

source code

Created on Sep 2, 2010

Author: dwmclary

Submodules | [hide private]
ziggy.GraphReduce ziggy.GraphReduce.Degree_mapper: Created on Aug 25, 2010 ziggy.GraphReduce.Degree_reducer: Created on Aug 25, 2010 ziggy.GraphReduce.GraphLoader: Created on Aug 11, 2010 ziggy.GraphReduce.LostMass_mapper: Created on Aug 18, 2010 ziggy.GraphReduce.LostMass_reducer: Created on Aug 18, 2010 ziggy.GraphReduce.PBFS_mapper: Created on Aug 12, 2010 ziggy.GraphReduce.PBFS_reducer: Created on Aug 12, 2010 ziggy.GraphReduce.PageRank_mapper: Created on Aug 18, 2010 ziggy.GraphReduce.PageRank_reducer: Created on Aug 18, 2010 ziggy.GraphReduce.gr_link_analysis: Created on Aug 18, 2010 ziggy.GraphReduce.gr_path: Created on Aug 12, 2010 ziggy.GraphReduce.hadoop_config: Created on May 17, 2010 Generic configuration parameters for Hadoop-based python modules ziggy.hdmc: Created on Jul 28, 2010 ziggy.hdmc.checkpoint_frame ziggy.hdmc.code_generator: Created on Jul 28, 2010 ziggy.hdmc.frame ziggy.hdmc.hadoop_config ziggy.hdmc.hdfs: Created on Jul 28, 2010 Access functions for files and directories stored in HDFS (Hadoop File System). ziggy.hdmc.hdfs.hdfs_access: Created on May 17, 2010 ziggy.hdmc.hdfs.hdfs_config ziggy.hdmc.hdmc: Module for running monte carlo and other batch jobs on a Hadoop instance. ziggy.hdmc.hdmc_tests: Created on Jul 29, 2010 ziggy.util

Variables | [hide private]
| __package__ = ``'``ziggy``'``